@@ -26,17 +26,19 @@ pub enum ReserveResult {
 #[async_trait]
 pub trait InventoryController {
     async fn reserve_items(&mut self, _items: &Vec<Item>) -> Result<ReserveResult, Error> {
-        let deadline = Utc::now() + Duration::days(1);
+        let deadline = Utc::now() + Duration::days(365);
         Ok(ReserveResult::Success(deadline))
     }
 
     async fn free_items(&mut self, _items: &Vec<Item>) -> Result<(), Error> {
         Ok(())
     }
-}
 
-#[async_trait]
-pub trait StockController {
-    async fn add_stock(&mut self, stock_units: &Vec<StockUnit>) -> Result<(), Error>;
-    async fn remove_stock(&mut self, stock_units: &Vec<StockUnit>) -> Result<(), Error>;
+    async fn add_stock(&mut self, _stock_units: &Vec<StockUnit>) -> Result<(), Error> {
+        Ok(())
+    }
+
+    async fn remove_stock(&mut self, _stock_units: &Vec<StockUnit>) -> Result<(), Error> {
+        Ok(())
+    }
 }
