@@ -9,6 +9,7 @@ use crate::payment::Initiator;
 use crate::payment::Payment;
 use crate::payment::PaymentProcessor;
 
+use super::reconcile;
 use super::LookupKey;
 use super::Order;
 use super::OrderState;
@@ -111,7 +112,7 @@ pub async fn reconcile_handler<C: Context + Send>(
 
     let mut od = maybe_order.unwrap();
 
-    od.reconcile(ctx).await
+    reconcile(ctx, &mut od).await
 }
 
 async fn get_order_by_checkout_id<C: Context + Send>(
